summaryrefslogtreecommitdiffstats
path: root/kwin/clients/quartz/quartz.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/clients/quartz/quartz.cpp')
-rw-r--r--kwin/clients/quartz/quartz.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kwin/clients/quartz/quartz.cpp b/kwin/clients/quartz/quartz.cpp
index 91ff39b7a..0435bb168 100644
--- a/kwin/clients/quartz/quartz.cpp
+++ b/kwin/clients/quartz/quartz.cpp
@@ -437,7 +437,7 @@ void QuartzButton::setBitmap(const unsigned char *bitmap)
if (bitmap) {
deco = new TQBitmap(10, 10, bitmap, true);
deco->setMask( *deco );
- tqrepaint( false );
+ repaint( false );
}
}
@@ -643,8 +643,8 @@ void QuartzClient::reset( unsigned long changed )
{
if (changed & SettingColors || changed & SettingFont)
{
- // tqrepaint the whole thing
- widget()->tqrepaint(false);
+ // repaint the whole thing
+ widget()->repaint(false);
}
KCommonDecoration::reset(changed);